@@ -55,7 +55,7 @@ __END__
 
 =head1 NAME
 
-Goo::DatabaseThing::Deleter - Delete a row from a table
+Goo::DatabaseThing::Deleter - Delete a row from a database table
 
 =head1 SYNOPSIS
 
@@ -63,8 +63,6 @@ use Goo::DatabaseThing::Deleter;
 
 =head1 DESCRIPTION
 
-
-
 =head1 METHODS
 
 =over
@@ -78,7 +76,7 @@ edit a task
 
 =head1 AUTHOR
 
-Nigel Hamilton <nigel@turbo10.com>
+Nigel Hamilton <nigel@trexy.com>
 
 =head1 SEE ALSO
 
